﻿using System.Windows;
using System.Collections.Generic;

using DevExpress.Data;
using DevExpress.Xpf.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 샘플 데이터 리스트
        /// </summary>
        private List<SampleData> sampleDataList;

        /// <summary>
        /// 빈 셀 전체 수
        /// </summary>
        private int emptyCellTotalCount = 0;

        /// <summary>
        /// 빈 셀 그룹 수
        /// </summary>
        private int emptyCellGroupCount = 0;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.sampleDataList = new List<SampleData>();

            for(int i = 0; i < 100; i++)
            {
                this.sampleDataList.Add(new SampleData() { Text = "group " + i % 10, Number = i });

                if(i % 3 == 0)
                {
                    this.sampleDataList[i].Number = null;
                }
            }

            this.gridControl.ItemsSource = this.sampleDataList;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 컨트롤 커스텀 요약 처리하기 - gridControl_CustomSummary(sender, e)

        /// <summary>
        /// 그리드 컨트롤 커스텀 요약 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridControl_CustomSummary(object sender, CustomSummaryEventArgs e)
        {
            if((e.Item as GridSummaryItem).FieldName != "Number")
            {
                return;
            }

            if(e.IsTotalSummary)
            {
                if(e.SummaryProcess == CustomSummaryProcess.Start)
                {
                    this.emptyCellTotalCount = 0;
                }

                if(e.SummaryProcess == CustomSummaryProcess.Calculate)
                {
                    int? fieldValue = (int?)e.FieldValue;

                    if(!fieldValue.HasValue)
                    {
                        this.emptyCellTotalCount++;
                    }

                    e.TotalValue = this.emptyCellTotalCount;
                }
            }

            if(e.IsGroupSummary)
            {
                if(e.SummaryProcess == CustomSummaryProcess.Start)
                {
                    this.emptyCellGroupCount = 0;
                }

                if(e.SummaryProcess == CustomSummaryProcess.Calculate)
                {
                    int? fieldValue = (int?)e.FieldValue;

                    if(!fieldValue.HasValue)
                    {
                        this.emptyCellGroupCount++;
                    }

                    e.TotalValue = this.emptyCellGroupCount;
                }
            }
        }

        #endregion
    }
}